| Title: | Interactive Document for Working with Goodness of Fit Analysis |
|---|---|
| Description: | An interactive document on the topic of goodness of fit analysis using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://predanalyticssessions1.shinyapps.io/ChiSquareGOF/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-26 08:36:48 UTC |
| Source: | https://github.com/cran/GOFShiny |
GOFShiny() loads interactive user interface built using R 'shiny'.
GOFShiny()GOFShiny()
Start GOFShiny
The interactive user interface is to provide an easy way for goodness of fit test analysis.
Nothing
if(interactive()){ library(rmarkdown) GOFShiny() }if(interactive()){ library(rmarkdown) GOFShiny() }